@@ -114,7 +114,7 @@ def declarative_base(cls=None, class_factory=None, settings=None, apps=None):
     return Base, target_metadata
 
 
-def destroy_engines():
+def destroy_engines(loop=None):
     """Destroys all known engines."""
     for name in list(dict.keys(ENGINES)):
         engine = ENGINES.pop(name)
@@ -122,7 +122,9 @@ def destroy_engines():
 
     for name in list(dict.keys(ASYNC_ENGINES)):
         engine = ASYNC_ENGINES.pop(name)
-        asyncio.run(engine.dispose())
+        asyncio.run(engine.dispose())\
+            if loop is None\
+            else loop.run_until_complete(engine.dispose())
 
 
 def create_engine(name='self', *args, **kwargs):
