@@ -6,10 +6,14 @@ class RelationalDatabaseRepository:
     """A repository implementation for use with :mod:`sqlalchemy`."""
     session_factory = 'AsyncSessionFactory'
 
+    async def query(self, q):
+        """Run a :class:`~unimatrix.ext.orm.query.Query` and return
+        the result(s).
+        """
+        return await q.run(self.session)
+
     async def __aenter__(self):
-        self._manages_session = False
         if getattr(self, 'session', None) is None:
-            self._manages_session = True
             if isinstance(self.session_factory, str):
                 self.session = ioc.require(self.session_factory)()
             elif callable(self.session_factory):
@@ -20,10 +24,12 @@ class RelationalDatabaseRepository:
                     ' attribute or implement it as a method.'
                 )
 
+        self._manages_session = not self.session.sync_session.in_transaction()
+
         # Determine if there is a transaction running. If a transaction is
         # running, start a savepoint, else begin a new one.
         begin = self.session.begin
-        if self.session.sync_session.in_transaction():
+        if not self._manages_session:
             begin = self.session.begin_nested
         self.tx = begin()
         await self.tx.__aenter__()
